function varargout = EigenValuesInWindowFigure(varargin)
% EIGENVALUESINWINDOWFIGURE M-file for EigenValuesInWindowFigure.fig
%      EIGENVALUESINWINDOWFIGURE, by itself, creates a new EIGENVALUESINWINDOWFIGURE or raises the existing
%      singleton*.
%
%      H = EIGENVALUESINWINDOWFIGURE returns the handle to a new EIGENVALUESINWINDOWFIGURE or the handle to
%      the existing singleton*.
%
%      EIGENVALUESINWINDOWFIGURE('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in EIGENVALUESINWINDOWFIGURE.M with the given input arguments.
%
%      EIGENVALUESINWINDOWFIGURE('Property','Value',...) creates a new EIGENVALUESINWINDOWFIGURE or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before EigenValuesInWindowFigure_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to EigenValuesInWindowFigure_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help EigenValuesInWindowFigure

% Last Modified by GUIDE v2.5 14-Mar-2005 23:25:29

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @EigenValuesInWindowFigure_OpeningFcn, ...
                   'gui_OutputFcn',  @EigenValuesInWindowFigure_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin & isstr(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT

%========================================================================================================================
% --- Executes just before EigenValuesInWindowFigure is made visible.
function EigenValuesInWindowFigure_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to EigenValuesInWindowFigure (see VARARGIN)

% Choose default command line output for EigenValuesInWindowFigure
handles.output = hObject;

handles.baseFigure=varargin{1};

%handles.plotFigure=figure;

% Update handles structure
guidata(hObject, handles);


% UIWAIT makes EigenValuesInWindowFigure wait for user response (see UIRESUME)
% uiwait(handles.figure1);

%========================================================================================================================
% --- Outputs from this function are returned to the command line.
function varargout = EigenValuesInWindowFigure_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;

%========================================================================================================================
% --- Executes on button press in pushbuttonClose.
function pushbuttonClose_Callback(hObject, eventdata, handles)
% hObject    handle to pushbuttonClose (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

%delete(handles.plotFigure);
delete(handles.figure1);

%========================================================================================================================
% --- Executes on button press in pushbuttonGo.
function pushbuttonGo_Callback(hObject, eventdata, handles)
% hObject    handle to pushbuttonGo (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

global SERIES
global SERIESINDEX
global SERIESTYPE
global SERIESSTAT

global TEMPX
global TEMPY

handles2=guidata(handles.baseFigure);
index=get(handles2.listbox1,'Value');
SRC=SERIES{index};

windowSize=str2num(get(handles.editWindowSize,'String'));
windowStep=str2num(get(handles.editWindowStep,'String'));

TEMPX=calculateEVWindow(SRC,windowSize,windowStep);
clear windowSize windowStep STR;

[m,n]=size(TEMPX);
for i=m:-1:1
    if (i==m)
        STR=blanks_w2('max',5);
    elseif (i==1)
        STR=[STR; blanks_w2('min',5)];
    else
        STR=[STR; blanks_w2(num2str(i),5)];
    end
end
set(handles.listboxEV,'String',STR);
clear STR;

% --- Executes during object creation, after setting all properties.
function editWindowSize_CreateFcn(hObject, eventdata, handles)
% hObject    handle to editWindowSize (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end

function editWindowSize_Callback(hObject, eventdata, handles)
% hObject    handle to editWindowSize (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of editWindowSize as text
%        str2double(get(hObject,'String')) returns contents of editWindowSize as a double


% --- Executes during object creation, after setting all properties.
function editWindowStep_CreateFcn(hObject, eventdata, handles)
% hObject    handle to editWindowStep (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end

function editWindowStep_Callback(hObject, eventdata, handles)
% hObject    handle to editWindowStep (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of editWindowStep as text
%        str2double(get(hObject,'String')) returns contents of editWindowStep as a double


% --- Executes during object creation, after setting all properties.
function listboxEV_CreateFcn(hObject, eventdata, handles)
% hObject    handle to listboxEV (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: listbox controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end


% --- Executes on selection change in listboxEV.
function listboxEV_Callback(hObject, eventdata, handles)
% hObject    handle to listboxEV (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns listboxEV contents as cell array
%        contents{get(hObject,'Value')} returns selected item from listboxEV


% --- Executes on button press in pushbutton7.
function pushbutton7_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton7 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

global SERIES
global SERIESINDEX
global SERIESTYPE
global SERIESSTAT

global TEMPX

handles2=guidata(handles.baseFigure);
index=get(handles2.listbox1,'Value');
RES=TEMPX(get(handles.listboxEV,'Value'),:);
SERIESINDEX=SERIESINDEX+1;
SERIES{SERIESINDEX}  =RES;
SERIESTYPE{SERIESINDEX}  =[char(SERIESTYPE{index}) ';WNDE'];
SERIESSTAT{SERIESINDEX}  =getStat(RES);
SERIESSTAT{SERIESINDEX}.fileName=SERIESSTAT{index}.fileName;
CD=get(handles2.listbox1,'String');
[CDm,CDn]=size(CD);
STR=get(handles.listboxEV,'String');
STR=STR(get(handles.listboxEV,'Value'),:);
CD(CDm+1,:)=blanks_w2(STR,8);
set(handles2.listbox1,'String',CD);
clear index RES STR;